from datetime import datetime
from nonebot_plugin_orm import Model
from sqlalchemy.orm import Mapped, mapped_column
from sqlalchemy import DateTime


class Record(Model):
    id: Mapped[int] = mapped_column(primary_key=True)
    source: Mapped[str]
    origin: Mapped[str]
    sender: Mapped[str]
    time: Mapped[datetime] = mapped_column(DateTime, default=datetime.now)

    __tablename__  = "alchelper_record"



"""0_5_0

迁移 ID: a9a3810efa4a
父迁移: 
创建时间: 2024-03-17 15:44:38.104506

"""
from __future__ import annotations

from collections.abc import Sequence

from alembic import op
import sqlalchemy as sa


revision: str = 'a9a3810efa4a'
down_revision: str | Sequence[str] | None = None
branch_labels: str | Sequence[str] | None = ('nonebot_plugin_alchelper',)
depends_on: str | Sequence[str] | None = None


def upgrade(name: str = "") -> None:
    if name:
        return
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('alchelper_record',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('source', sa.String(), nullable=False),
    sa.Column('origin', sa.String(), nullable=False),
    sa.Column('sender', sa.String(), nullable=False),
    sa.Column('time', sa.DateTime(), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_alchelper_record')),
    info={'bind_key': 'nonebot_plugin_alchelper'}
    )
    # ### end Alembic commands ###


def downgrade(name: str = "") -> None:
    if name:
        return
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('alchelper_record')
    # ### end Alembic commands ###
